@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20210620';
+our $VERSION = '5.20210723';
 our %utilities;
 
 sub utilities {
@@ -1720,6 +1720,13 @@ my %delta = (
         removed => {
         }
     },
+    5.035002 => {
+        delta_from => 5.035001,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
